Installation
============

The source Python code of the package is currently hosted on GitHub at: https://github.com/3DFin/dendromatics

To install dendromatics, simply type the following command in a terminal::

    pip install 'dendromatics'

To load the package in your current Python session, simply type the following code in the Python interpreter::

    import dendromatics

    # or to bind it to a shorter, more convenient name:
    import dendromatics as dm